@@ -1,18 +1,3 @@
-`DebugPrint` <-
-function (x) {
-    if (isTRUE(getOption("debug.print"))) {
-		fun <- asChar(sys.call(sys.parent())[[1L]])
-		name <- substitute(x)
-		cat(sprintf("<%s> ~ ", fun))
-		if(is.language(name)) cat(asChar(name), "= \n")
-        print(x)
-    }
-}
-	
-`srcc` <- function() {
-	ret <- eval(expression(source("clipboard", local = TRUE)), .GlobalEnv)
-	return(if(ret$visible) ret$value else invisible(ret$value))
-}
 
 `cry` <-
 function(Call = NA, Message, ..., warn = FALSE, domain = paste0("R-", .packageName)) {
@@ -124,7 +109,6 @@ function(x) all(vapply(x[-1L], identical, logical(1L), x[[1L]]))
 }
 
 `clusterVExport` <- local({
-	
    `getv` <- function(obj, env = as.environment(1L))
 		for (i in names(obj)) assign(i, obj[[i]], envir = env)
 	function(cluster, ...) {
@@ -133,8 +117,7 @@ function(x) all(vapply(x[-1L], identical, logical(1L), x[[1L]]))
 		Call <- Call[-1L]
 		vars <- list(...)
 		vnames <- names(vars)
-		#if(!all(sapply(Call, is.name))) warning("at least some elements do not have syntactic name")
-		if(is.null(vnames)) {
+		if (is.null(vnames)) {
 			names(vars) <- vapply(Call, asChar, "")
 		} else if (any(vnames == "")) {
 			names(vars) <- ifelse(vnames == "", vapply(Call, asChar, ""), vnames)
@@ -293,3 +276,10 @@ function(x, y, ty = t(y)) {
 	return(rowSums(x * ty))
 }
 
+
+tmpvarname <- function(envir, n = 8L) {
+	while(exists(x <- paste0(c("*", sample(letters, n), "*"),
+		collapse = ""), envir)) {}
+	x
+}
+
